@@ -309,10 +309,23 @@ ui <- tagList(
     navbarMenu(
       title = "Modules",
       icon = icon("buromobelexperte"),
-      tabPanel("Import"),
-      tabPanel("Export"),
-      tabPanel("module 3")
-    ),
+      tabPanel("Import & Export"),
+      tabPanel("Data Tidy"),
+      tabPanel("General Analysis"),
+      tabPanel("Genomic Analysis"),
+      tabPanel("Visualization"
+               # ,
+               # fluidPage(
+               #   fluidRow(
+               #     helpText("The data query may take a long time, please be patient..."),
+               #     column(
+               #       12,
+               #       tabPanel("Gene Pan-cancer Expression",
+               #                plotOutput("vis_toil_gene"))
+               #     )
+               #   )
+               # )
+               )),
 
     # Pipelines page =====================
     navbarMenu(
@@ -643,6 +656,12 @@ server <- function(input, output, session) {
             title = "Tips",
             content = "Download zipped data to local",
             placement = "bottom", options = list(container = "body")
+          ),
+          downloadButton(outputId = "total_url", label = "URLs List", icon = icon("download"), style = "margin-bottom: 10px; margin-left: 75px;"),
+          shinyBS::bsPopover("total_url",
+                             title = "Tips",
+                             content = "Download list of target urls",
+                             placement = "bottom", options = list(container = "body")
           )
         )
       )
@@ -701,6 +720,15 @@ server <- function(input, output, session) {
     }
     output$detail_info <- DT::renderDT(m, options = list(dom = "t", scrollX = TRUE))
   })
+  
+  # Download list of urls
+  output$total_url <- downloadHandler(
+    filename = "urls.txt",
+    contentType = "text/txt",
+    content = function(file) {
+      write.table(file = file, paste0("wget ", query_url()$url), row.names = F, col.names = F, quote = F)
+    }
+  )
 
 
   # Download request data by XenaDownload function
@@ -736,6 +764,13 @@ server <- function(input, output, session) {
     }
   )
 
+
+# Modules -----------------------------------------------------------------
+  # toil_df = ope_toil_gene()
+  # output$vis_toil_gene = renderPlot({
+  #   vis_toil_gene(toil_df)
+  # })
+  
   output$w <- renderText({
     req(input$side)
     r <- input$side
